summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorPali Rohár <pali.rohar@gmail.com>2021-01-05 12:32:34 +0100
committerPali Rohár <pali.rohar@gmail.com>2021-01-05 12:32:34 +0100
commit0e5ceffa421c5d667e74641f864ac99109908f7d (patch)
treef2481dfa761462b8e61cc1fb85a270392483220c /src
parentca080dd33f723c0632a041f6c9bb7b15d2fdaa32 (diff)
download0xFFFF-0e5ceffa421c5d667e74641f864ac99109908f7d.tar.bz2
disk: Fix detecting Nokia N9 device
Diffstat (limited to 'src')
-rw-r--r--src/disk.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/disk.c b/src/disk.c
index 99fb7c8..38fbb09 100644
--- a/src/disk.c
+++ b/src/disk.c
@@ -414,8 +414,8 @@ int disk_init(struct usb_device_info * dev) {
/* TODO: change 1 to 0 when disk_flash_dev will be implemented */
- /* RX-51 and RM-680 export MyDocs in first usb device and just first partion, so host system see whole device without MBR table */
- if ( dev->device == DEVICE_RX_51 || dev->device == DEVICE_RM_680 )
+ /* RX-51, RM-680 and RM-696 export MyDocs in first usb device and just first partion, so host system see whole device without MBR table */
+ if ( dev->device == DEVICE_RX_51 || dev->device == DEVICE_RM_680 || dev->device == DEVICE_RM_696 )
fd = disk_open_dev(maj1, min1, -1, 1);
/* Other devices can export SD card as first partition and export whole mmc device, so host system will see MBR table */
else if ( maj2 != -1 && min2 != -1 )